@@ -8,7 +8,6 @@ File: mongo_op.py
 Date: 2020/8/19 9:58 上午
 '''
 
-
 import pymongo
 from pymongo import UpdateOne, InsertOne
 from .config_log import config
@@ -27,8 +26,7 @@ def get_client(label='mongo', **kwargs):
         )
     else:
         my_client = pymongo.MongoClient(
-            'mongodb://{0}:{1}/'. \
-                format(config(label, 'host'), config(label, 'port')),
+            config(label, 'host'), # mongodb://user:password@192.168.6.28:3017/db
             unicode_decode_error_handler='ignore',
             **kwargs
         )
@@ -93,7 +91,8 @@ class MongoOp(object):
         """
         try:
             return self.col.insert_one(write_dict)
-        except:
+        except Exception as e:
+            raise e
             pass
 
     def insert(self, write_dict):
@@ -130,7 +129,8 @@ class MongoOp(object):
 def message_more_cache_expire_index():
     mg_op = MongoOp('xiaomu', 'message_more_cache', label='mongo')
     mg_op.drop_index('time_-1')
-    mg_op.create_index([("time", pymongo.DESCENDING)], expireAfterSeconds=3600*18)
+    mg_op.create_index([("time", pymongo.DESCENDING)], expireAfterSeconds=3600 * 18)
+
 
 if __name__ == '__main__':
     mg_op = MongoOp('xiaomu', 'knowledge_map', label='mongo')
@@ -143,4 +143,3 @@ if __name__ == '__main__':
     r = mg_op.find({'type': 'teacher'})
     print(r)
     mg_op.close()
-
