@@ -15,6 +15,7 @@ import pandas as pd
 from .config_log import config
 from multiprocessing import Pool
 from sqlalchemy import create_engine
+from urllib.parse import quote_plus
 from .data_to_str import DataTypeToStr
 from .utils import MyException
 
@@ -54,7 +55,7 @@ class ConMysql(object):
                     host=self._host,
                     port=self._port,
                     user=self._user,
-                    passwd=self._password,
+                    passwd=quote_plus(self._password),
                     db=self._db_name,
                 ), connect_args={'charset': 'utf8'},
                     pool_size=5,
